<?php
/**
 * Controller is the customized base controller class.
 * All controller classes for this application should extend from this base class.
 */
class Controller extends CController
{	
	/**
	 * @var string the default layout for the controller view. Defaults to '//layouts/column1',
	 * meaning using a single column layout. See 'protected/views/layouts/column1.php'.
	 */
	public $layout='//layouts/column1';
	/**
	 * @var array context menu items. This property will be assigned to {@link CMenu::items}.
	 */
	public $menu=array();
	/**
	 * @var array the breadcrumbs of the current page. The value of this property will
	 * be assigned to {@link CBreadcrumbs::links}. Please refer to {@link CBreadcrumbs::links}
	 * for more details on how to specify this property.
	 */
	public $breadcrumbs=array();
	
	
	
	/**
	 * private global variables
	 */
	protected static $playerImagePath = 'images/player_pictures/';
	protected static $teamImagePath = 'images/team_pictures/';
	protected static $newsImagePath = 'images/news_pictures/';
	protected static $subPageBlogImagePath = 'images/subpage_simple_blog_pictures/';
	
	public $currClubUrl = Null;
	public $currClubId = Null;
	public $currClubName = Null;
	
	/**
	 * // TODO: description
	 * given a clubUrl, the corresponding club id will be determined
	 * given a clubId, a check if the $clubId exists will be performed.
	 * 
	 * If a clubUrl is given, the clubId parameter will not be considered.
	 * 
	 * If no parameters are given at all, the session parameter  
	 * @param string $clubId
	 * @param string $clubUrl
	 * @return Ambigous <NULL, unknown>
	 */
	public static function getClubId($clubId=Null, $clubUrl=Null) {
		
		$clubID = -1;
		if(isset($clubUrl)) {
			$club = Club::model()->findByAttributes(array('url' => $clubUrl));
			if(isset($club)) { 
				$clubId = $club->club_id;
// 				$this->currClubUrl = $clubUrl;
// 				$this->currClubName = $club->name;				
			} 
		}
		
		if(isset($clubId)) {
			$clubID = $clubId;
		}
		else {
			$id  = Yii::app()->user->getState('club_id');
			if(isset($id)) {
				$clubID = $id;
			}								
		}
		
// 		if(!isset($this->currClubUrl)) {
// 			$tmpClub = Club::model()->findByPk($clubID);
// 			if(isset($tmpClub)) {
// 				$this->currClubUrl = $tmpClub->url;
// 				$this->currClubName = $tmpClub->name;
// 			}			
// 		}		
		
// 		$this->currClubId = $clubID;		
		return $clubID;
	}
	
	/**
	 * 
	 * @param unknown $clubId
	 * @return string
	 */
	public static function getClubName($clubId) {
		
		if(isset($clubId)) {
			$club = Club::model()->findByPk($clubId);
			if(isset($club)) {
				return $club->name;
			}
		}
		
		return 'No Name: ';
	}
	
	/**
	 *
	 * @param unknown $clubId
	 * @return string
	 */
	public static function getClubUrl($clubId) {
	
		if(isset($clubId)) {
			$club = Club::model()->findByPk($clubId);
			if(isset($club)) {
				return $club->url;
			}
		}
	
		return null;
	}
	
	/**
	 * overwritten createUrl function that inludes the club id
	 * within the url if no club url was found.
	 * 
	 * @param unknown $route
	 * @param unknown $params
	 * @param string $ampersand
	 * @return string
	 */
	public function createUrl($route, $params=array ( ), $ampersand='&') {
		
		$url = parent::createUrl($route, $params, $ampersand);
		
		if(isset($_GET['clubUrl'])) {
			// TODO ??
		}
		else {
			if(isset($_GET['clubId'])) {
				$url = $url . '/clubId/' . $_GET['clubId'];
			}
			else {
				$cId  = Yii::app()->user->getState('club_id');
				if(isset($cId)) {
					$url = $url . '/clubId/' . $cId;
				}
			}
		}
		
		return $url;
	}
	
	public function createAbsoluteUrl($route, $params=array ( ), $schema='', $ampersand='&') {
	
		$url = parent::createAbsoluteUrl($route, $params, $schema, $ampersand);
	
		if(isset($_GET['clubUrl'])) {
			// TODO ??
		}
		else {
			if(isset($_GET['clubId'])) {
				$url = $url . '/clubId/' . $_GET['clubId'];
			}
			else {
				$cId  = Yii::app()->user->getState('club_id');
				if(isset($cId)) {
					$url = $url . '/clubId/' . $cId;
				}
			}
		}
	
		return $url;
	}
	
	/**
	 * 
	 * @param unknown $action
	 * @return boolean
	 */
	protected function beforeAction($action) {
		
		/*
		* global time parameter so we can use php time/date functions.
		*/
		date_default_timezone_set('Europe/Berlin');	
		
// 		self::$playerImagePath = Yii::app()->request->baseUrl.'/images/player_pictures/';
// 		self::$teamImagePath = Yii::app()->request->baseUrl.'/images/team_pictures/';
// 		self::$newsImagePath = Yii::app()->request->baseUrl.'/images/news_pictures/';
	
		return true;
	}
	
	/**
	 * 
	 * @param unknown $view
	 * @param unknown $output
	 * @return boolean
	 */
	protected function afterRender($view, &$output) {
		
		parent::afterRender($view,$output);
		//Yii::app()->facebook->addJsCallback($js); // use this if you are registering any $js code you want to run asyc
		Yii::app()->facebook->initJs($output); // this initializes the Facebook JS SDK on all pages
		Yii::app()->facebook->renderOGMetaTags(); // this renders the OG tags
		return true;
	}
}