<?php

/*
 * Component for creating the RBAC structure
 *
 * @author scheer
 */
class RbacComponent extends CApplicationComponent {
    
    
    public function createHierarchy() {
    	
    	$auth=Yii::app()->authManager;
    	
    	$auth->createOperation('read_post','read posts');
    	$auth->createOperation('create_post','create posts');
    	$auth->createOperation('comment_post','create comments for a post');
    	$auth->createOperation('edit_post','edit posts');
    	
    	$bizRule='return Yii::app()->user->id==$params["post"]->u_id;';
    	$task = $auth->createTask('edit_own_post','edit own posts', $bizRule);
    	$task->addChild('edit_post');
    	
    	
    	
    	
    	$this->createNewsRoles($auth);
    	$this->createClubManagmentRoles($auth);
    	$this->createAdminRole($auth);
    }
    
    
    private function createNewsRoles($auth = Null) {
    	
    	$bizRule='return !Yii::app()->user->isGuest;';
    	$role = $auth->createRole('reader', 'Can only read posts', $bizRule);
    	$role->addChild('read_post');
    	 
    	$role = $auth->createRole('commentor', 'Can read posts and write comments');
    	$role->addChild('reader');
    	$role->addChild('comment_post');
    	 
    	$role = $auth->createRole('author', 'Can create posts');
    	$role->addChild('commentor');
    	$role->addChild('create_post');
    	$role->addChild('edit_own_post');
    	 
    	$role = $auth->createRole('editor', 'Can edit and create posts');
    	$role->addChild('author');
    	$role->addChild('edit_post');
    }
    
    /**
     * 
     * @param string $auth
     */
    private function createClubManagmentRoles($auth = Null) {
    	
    	/**
    	 * club/team managment roles
    	 */
    	$role = $auth->createRole('team_manager', 'Can manage a team');
    	$role->addChild('editor');
    	 
    	$role = $auth->createRole('youth_executive', 'can manage youth teams');
    	$role->addChild('editor');
    	 
    	$role = $auth->createRole('club_manager', 'Can manage a club');
    	$role->addChild('youth_executive');
    }
    
    
    /**
     * 
     * @param string $auth
     */
    private function createAdminRole($auth = Null) {
    	
    	$role = $auth->createRole('admin', 'has superpowers (within a club)');
    	$role->addChild('editor');
    	$role->addChild('club_manager');
    	$role->addChild('team_manager');
    }
}

?>
