<?php


class SubPageController extends Controller
{
	
	
	public function actionViewSubPage($subPage_id=-1) {
		// subPage/viewSubPage/subPage_id/myID
		
		$isUser = (!Yii::app()->user->getIsGuest());
		$access = Yii::app()->user->checkAccess('club_manager');
		$canView = false;
		
		$subPage = SubPage::model()->findByPk($subPage_id);
		if(!isset($subPage)) {
			$this->redirect(Yii::app()->homeUrl);
			return;
		}
		
		if($isUser && $access) {
			$clubID = Yii::app()->user->getState('club_id');
			$userID = Yii::app()->user->id;
			
			/*
			 * user belongs to the same club, as the subPage he wants to delete
			*/
			if($subPage->club_id == $clubID) {
				$canView = true;
			}
		}
		else {
			/*
			 * we have a public subpage
			 */
			if($subPage->visibility == Visibility::_PUBLIC) {
				$canView = true;
			}
		}
		
		
		if($canView) {
			/*
			 * we have access to subpage now
			*/
			
			$subPageEntryModels = SubPageBlogEntry::model()->findAllByAttributes(array('subpage_id' => $subPage_id), array('order'=>'order_id DESC'));
			if(!$subPageEntryModels) {
				$subPageEntryModels = Null;
				
				$this->render('subPage', array('subPage' => $subPage, 'subPageEntryModels' => $subPageEntryModels));
				return;
			}
			
			$subPageEntryImages = array();
			foreach ($subPageEntryModels as $subPageEntryModel ) {
				
				
				
				// TODO: get images per blog entry
				
				$blogImages = SimpleBlogImage::model()->findAllByAttributes(
						array('subpage_simple_blog_id' => $subPageEntryModel->subpage_simple_blog_id) );
				$bImages = array();
				$imgIds = array();
				$fileNames = array();
				foreach ($blogImages as $image) {
					$tmpImage = ImageModel::model()->findByPk($image->img_id);
					if(isset($tmpImage) && isset($tmpImage->file_name) && file_exists($tmpImage->file_name)) {
						$easyImg = new EasyImage($tmpImage->file_name);
						$bImages[] = $easyImg;
						$imgIds[] = $image->img_id;
						$fileNames[] = $tmpImage->file_name;
					}
				}
				
				$subPageEntryImages[$subPageEntryModel->subpage_simple_blog_id] = array('bImages' => $bImages,
						'imgIds' => $imgIds, 'fileNames' => $fileNames);
			}
			
			$this->render('subPage', array('subPage' => $subPage, 'subPageEntryModels' => $subPageEntryModels,
				'subPageEntryImages' => $subPageEntryImages));
			return;
		}
		
		$this->redirect(Yii::app()->homeUrl);
		return;
	}
	
	public function actionCreateSubPage() {
		
		$isUser = (!Yii::app()->user->getIsGuest());
		$access = Yii::app()->user->checkAccess('club_manager');
		if($isUser && $access) {
			
			$subPageModel = new SubPage;
			$u_id = Yii::app()->user->id;
			
			
			if (Yii::app()->request->isAjaxRequest) {
				if(isset($_POST['SubPage'])) {
				
					$this->layout=false;
					header('Content-type: application/json');
					$subPageModel->name = $_POST['SubPage']['name'];
					
					$club_id = Yii::app()->user->getState('club_id');
					$subPageModel->club_id = $club_id;
					$date = CTimestamp::getDate(false, false, false);
					$subPageModel->date  = date('Y-m-d G:i:s', $date[0]);
					// $subPageModel->visibility = $_POST['SubPage']['visibility'];
					$subPageModel->visibility = 'public';
						
					$hasPrivileges = false;
					$validSubPage = $subPageModel->validate();
					if($validSubPage) {
						/*
						 * check if user really belongs to the given club
						 */
						$hasClub = HasClubs::model()->exists('u_id='.$u_id.'AND club_id='.($club_id));
						if($hasClub) {
							
							//Yii::log("errors saving subPageModel: " . var_export($subPageModel->getErrors(), true), CLogger::LEVEL_WARNING, __METHOD__);
							$hasPrivileges = $subPageModel->save();							
						}
					}
					
					echo CJSON::encode(array('valid' => ($validSubPage && $hasPrivileges), 'privileges' => $hasPrivileges));
					return;
				}
			}
			
			$this->render('clubAdministration');
			return;
		}		
		
		$this->redirect(Yii::app()->homeUrl);
		return;
	}
	
	
	
	public function actionCreateSubPageEntry($subPage_id) {
		$access = Yii::app()->user->checkAccess('club_manager');	// TODO: use team_manager role later
		$isUser = !Yii::app()->user->getIsGuest();
		if($isUser && $access) {
			$clubID = Yii::app()->user->getState('club_id');
			$userID = Yii::app()->user->id;
				
			
			// store all file names of the uploaded files in this array.
			// if any upload or a db action fails
			// all files within this array will be deleted
			$tmpUploadedFiles = array();
			$transaction = Yii::app()->db->beginTransaction();
			$dataAdded = Null;
			$subPageEntryModel = new SubPageBlogEntry;
			$subPage = Null;
			try
			{
				/*
				 * subPage exists
				*/
				$subPage = SubPage::model()->findByPk($subPage_id);
				if(!isset($subPage)) {
					throw new CDbException('cannot add subPageEntry. SubPage ' . $subPage_id .' does not exist.');
				}	
				$subPageEntryModel->subpage_id = $subPage_id;
				
				/*
				 * user belongs to the same club, as the subPage he wants to delete
				*/
				if($subPage->club_id != $clubID) {
					throw new CDbException('cannot add subPage. user does not belong to club '.$clubID.',
							but subPage ' . $subPage .' does.');
				}
				
				/*
				 * access checked.
				*/
				$blogImagePath = self::$subPageBlogImagePath;
				$blogEntrySuccessfulUpdated = false;
				
				/*
				 * Update simple blog entry, if we have POST-data for it.
				*/
				$dataAdded = false;
				if(isset($_POST['SubPageBlogEntry'])) {
					
					$subPageEntryModel->subpage_id = $subPage->subpage_id;
					$subPageEntryModel->title = $_POST['SubPageBlogEntry']['title'];
					$subPageEntryModel->text = $_POST['SubPageBlogEntry']['text'];
					$date = CTimestamp::getDate(false, false, false);
					$subPageEntryModel->date = date('Y-m-d G:i:s', $date[0]);
					$subPageEntryModel->order_id = -1;
					$subPageEntryModel->visibility = $_POST['SubPageBlogEntry']['visibility'];
					
					$blogImagePath = self::$subPageBlogImagePath;
					if($subPageEntryModel->validate()) {
						
						$subPageEntryModel->save();
						
						$uploadedFile= CUploadedFile::getInstancesByName('file_name');
						foreach ($uploadedFile as $file) {
								
							$tmp_image = new ImageModel;
							$tmp_image->date = $subPageEntryModel->date;
								
							$length = 20;
							$chars = array_merge(range(0,9), range('a','z'), range('A','Z'));
							shuffle($chars);
							$RandFileName = implode(array_slice($chars, 0, $length));
							$RandFileName = $blogImagePath.$RandFileName. $file->name;
							$tmp_image->file_name = $RandFileName;
							$tmpUploadedFiles[] = $RandFileName;
							if($tmp_image->validate()) {
								$fileSaved = $file->saveAs($RandFileName);
								if($fileSaved) {
									if($tmp_image->save()) {
						
										$simpleBlogEntryImage = new SimpleBlogImage;
										$simpleBlogEntryImage->subpage_simple_blog_id = $subPageEntryModel->subpage_simple_blog_id;
										$simpleBlogEntryImage->img_id = $tmp_image->img_id;
										if($simpleBlogEntryImage->validate()) {
											$simpleBlogEntryImage->save();
										}
									}
								}
								else
									throw new CHttpException('could not upload Image');
						
							}
							else
								throw new CDbException('could not validate the ImageModel');
						}
						
						$dataAdded = true;
						$transaction->commit();
					}
				}
				else {
					$dataAdded = Null;
				}
			}
			catch (Exception $e) {
				
				
				
				$transaction->rollback();
				
				foreach ($tmpUploadedFiles as $fileName) {
					if(file_exists($fileName)) {
						unlink($fileName);
					}
				}
				
				$this->render('clubAdministration');		// TODO: Error message if something goes wrong
				return;
			}
			
			$this->render('addSubPageEntry', array('subPageEntryModel'=> $subPageEntryModel, 'subPage' => $subPage, 
					'dataAdded' => $dataAdded));
			return;
		}
		
		$this->redirect(Yii::app()->homeUrl);
		return;
	}
	
	public function actionActivateSubPage($subPage_id) {
		
		$access = Yii::app()->user->checkAccess('club_manager');	// TODO: use team_manager role later
		$isUser = !Yii::app()->user->getIsGuest();
		if($isUser && $access) {
			$clubID = Yii::app()->user->getState('club_id');
			$userID = Yii::app()->user->id;
			
			$transaction = Yii::app()->db->beginTransaction();
			try
			{
				/*
				 * subPage exists
				*/
				$subPage = SubPage::model()->findByPk($subPage_id);
				if(!isset($subPage)) {
					throw new CDbException('cannot delete subPage. subPage ' . $subPage_id .' does not exist.');
				}
				
				/*
				 * user belongs to the same club, as the subPage he wants to delete
				*/
				if($subPage->club_id != $clubID) {
					throw new CDbException('cannot delete subPage. user does not belong to club '.$clubID.',
							but subPage ' . $subPage_id .' does.');
				}
				
				$subPage->active=!$subPage->active;
				
				if($subPage->validate('active')) {
					$updated = $subPage->update('active');
					if(!$updated) {
						throw new CDbException('can save update subPage. Update error');
					}
				}
				else {
					throw new CDbException('can update subPage. Validation error');
				}
				
				$transaction->commit();
			}
			catch (Exception $e) {
				$transaction->rollback();
			}
			
			$this->redirect($this->createUrl('subPage/subPageEditOverview'));
		}
		
		$this->redirect(Yii::app()->homeUrl);
		return;
	}
	
	
	public function actionDeleteSubPage($subPage_id) {
	
		$access = Yii::app()->user->checkAccess('club_manager');	// TODO: use team_manager role later
		$isUser = !Yii::app()->user->getIsGuest();
		if($isUser && $access) {
			$clubID = Yii::app()->user->getState('club_id');
			$userID = Yii::app()->user->id;
			
			$transaction = Yii::app()->db->beginTransaction();
			try
			{
				/*
				 * subPage exists
				 */
				$subPage = SubPage::model()->findByPk($subPage_id);
				if(!isset($subPage)) {
					throw new CDbException('cannot delete subPage. subPage ' . $subPage_id .' does not exist.');
				}
				
				/*
				 * user belongs to the same club, as the subPage he wants to delete
				*/
				if($subPage->club_id != $clubID) {
					throw new CDbException('cannot delete subPage. user does not belong to club '.$clubID.', 
							but subPage ' . $subPage_id .' does.');
				}
				
				
				// TODO: Get and delete all subpage entries with its images
				//		 Also delete images from disk.
				
				if(!$subPage->delete()) {
					throw new CDbException('cannot delete subPage. Deleting from database failed');
				}
				
				$transaction->commit();
			}
			catch (Exception $e) {
				$transaction->rollback();
			
				// 				throw new CException($e->getMessage());
			}

			$this->redirect($this->createUrl('subPage/subPageEditOverview'));
		}
		
		$this->redirect(Yii::app()->homeUrl);
		return;
	}
	
	
	
	public function actionDeleteSubPageEntry($subpage_simple_blog_id) {
	
		$access = Yii::app()->user->checkAccess('club_manager');	// TODO: use team_manager role later
		$isUser = !Yii::app()->user->getIsGuest();
		if($isUser && $access) {
			$clubID = Yii::app()->user->getState('club_id');
			$userID = Yii::app()->user->id;
				
			$transaction = Yii::app()->db->beginTransaction();
			try
			{
				/*
				 * subPageEntry exists
				*/
				$subpageSimpleEntryId = SubPageBlogEntry::model()->findByPk($subpage_simple_blog_id);
				if(!isset($subpageSimpleEntryId)) {
					throw new CDbException('cannot delete subPage. subPage ' . $subpage_simple_blog_id .' does not exist.');
				}
				
				
				/*
				 * subPage exists
				*/
				$subPage = SubPage::model()->findByPk($subpageSimpleEntryId->subpage_id);
				if(!isset($subPage)) {
					throw new CDbException('cannot delete subPageEntry. ' . $subpageSimpleEntryId->subpage_id .' does not exist.');
				}
				
	
				/*
				 * user belongs to the same club, as the subPage he wants to delete
				*/
				if($subPage->club_id != $clubID) {
					throw new CDbException('cannot delete subPage. user does not belong to club '.$clubID.',
							but subPage ' . $subPage .' does.');
				}
	
				if(!$subpageSimpleEntryId->delete()) {
					throw new CDbException('cannot delete subPage. Deleting from database failed');
				}
	
				$transaction->commit();
			}
			catch (Exception $e) {
				$transaction->rollback();
					
				// 				throw new CException($e->getMessage());
			}
			
			$this->redirect($this->createUrl('subPage/subPageEditOverview'));
		}
	
		
		$this->redirect(Yii::app()->homeUrl);
		return;
	}
	
	
	public function actionDeleteSimpleBlogImage($subPageEntry_id=Null) {
		
		$access = Yii::app()->user->checkAccess('club_manager');	// TODO: use team_manager role later
		$isUser = !Yii::app()->user->getIsGuest();
		if($isUser && $access) {
			$clubID = Yii::app()->user->getState('club_id');
			$userID = Yii::app()->user->id;
			
// 			$transaction = Yii::app()->db->beginTransaction();
// 			try
// 			{
			/*
			 * subPageEntry exists
			*/
			$subpageSimpleEntry = SubPageBlogEntry::model()->findByPk($subPageEntry_id);
			if(!isset($subpageSimpleEntry)) {
				throw new CDbException('cannot delete image. subPage entry' . $subPageEntry_id .' does not exist.');
			}
			
			/*
			 * subPage exists
			*/
			$subPage = SubPage::model()->findByPk($subpageSimpleEntry->subpage_id);
			if(!isset($subPage)) {
				throw new CDbException('cannot delete image. ' . $subpageSimpleEntryId->subpage_id .' does not exist.');
			}
			
			/*
			 * user belongs to the same club, as the subPage he wants to delete
			*/
			if($subPage->club_id != $clubID) {
				throw new CDbException('cannot delete subPage. user does not belong to club '.$clubID.',
						but subPage ' . $subPage .' does.');
			}
			
			$delImg= Null;
			if (Yii::app()->request->isAjaxRequest) {
				$isDeleted = false;
				$this->layout=false;
				header('Content-type: application/json');
				
				if(isset($_POST['img_id'])) {
					$delImgId = $_POST['img_id'];
				}
				else {
					echo CJSON::encode(array('valid' => false));
					return;
				}
				
				
				$delError = '';

				$transaction = Yii::app()->db->beginTransaction();
				try
				{
								
					$blogImage = SimpleBlogImage::model()->findByAttributes(
							array('img_id' => $delImgId, 'subpage_simple_blog_id' => $subPageEntry_id));
					if(isset($blogImage) && $blogImage!=NULL) {
						
						$tmpImage = ImageModel::model()->findByPk($delImgId);
						if(isset($tmpImage->file_name) && file_exists($tmpImage->file_name)) {
							$delImg = $tmpImage->file_name;
						}
						
						$blogImage->delete();						
						$tmpImage->delete();
						$isDeleted = true;
						
						$transaction->commit();
					}
				}
				catch (Exception $e) {
					$transaction->rollback();
					$isDeleted = false;
				}

				
				if(isset($delImg)) {
					unlink($delImg);
				}
	
				echo CJSON::encode(array('valid' => $isDeleted));
				return;
			}
			
			// no ajax request arrived: TODO: go to edit entry page
			$this->redirect($this->createUrl('subPage/subPageEditOverview'));
		}
		
		$this->redirect(Yii::app()->homeUrl);
		return;
	}
	
	
	public function actionEditSubPageEntryOverview($subPage_id) {
	
		$isUser = (!Yii::app()->user->getIsGuest());
		$access = Yii::app()->user->checkAccess('club_manager');
		if($isUser && $access) {	
			$clubID = Yii::app()->user->getState('club_id');	
			$userID = Yii::app()->user->id;
			
			
			/*
			 * subPage exists
			*/
			$subPage = SubPage::model()->findByPk($subPage_id);
			if(!isset($subPage)) {
				//throw new CDbException('cannot edit subPageEntry. ' . $subpageSimpleEntry->subpage_id .' does not exist.');
				$this->redirect(Yii::app()->homeUrl); // TODO: different redirect
			}
			
			
			
			$subPageEntryModels = SubPageBlogEntry::model()->findAllByAttributes(array('subpage_id' => $subPage_id), array('order'=>'order_id DESC'));
			if(!$subPageEntryModels) {
				$subPageEntryModels = Null;
			}
			
			$this->render('editSubPageEntryOverview', array('subPageEntryModels'=> $subPageEntryModels, 'subPage' => $subPage));
			return;
			
		}
		$this->redirect(Yii::app()->homeUrl);
	}

	
	
	public function actionEditSubPageEntry($subPageEntry_id=-1) {
	
		$isUser = (!Yii::app()->user->getIsGuest());
		$access = Yii::app()->user->checkAccess('club_manager');
		if($isUser && $access) {
					
			$clubID = Yii::app()->user->getState('club_id');
			$userID = Yii::app()->user->id;
			
			// store all file names of the uploaded files in this array.
			// if any upload or a db action fails
			// all files within this array will be deleted
			$tmpUploadedFiles = array();
			$transaction = Yii::app()->db->beginTransaction();
			try
			{
				/*
				 * subPageEntry exists
				*/ 
				$subpageSimpleEntry = SubPageBlogEntry::model()->findByPk($subPageEntry_id);
				// TODO: change !isset(myVal) with !myVal
				if(!isset($subpageSimpleEntry)) {
					throw new CDbException('cannot edit subPageEntry. subPageEntry ' . $subPageEntry_id .' does not exist.');
				}
				
				
				/*
				 * subPage exists
				*/
				$subPage = SubPage::model()->findByPk($subpageSimpleEntry->subpage_id);
				if(!isset($subPage)) {
					throw new CDbException('cannot edit subPageEntry. ' . $subpageSimpleEntry->subpage_id .' does not exist.');
				}
				
				
				/*
				 * user belongs to the same club, as the subPage he wants to delete
				*/
				if($subPage->club_id != $clubID) {
					throw new CDbException('cannot delete subPage. user does not belong to club '.$clubID.',
							but subPage ' . $subPage .' does.');
				}
				
				
				/*
				 * access checked.
				 */
				$blogImagePath = self::$subPageBlogImagePath;
				$blogEntrySuccessfulUpdated = false;				
				
				/*
				 * Update simple blog entry, if we have POST-data for it.
				 */
				$entrySuccessfulUpdated = false;
				if(isset($_POST['SubPageBlogEntry'])) {
					
					$date = CTimestamp::getDate(false, false, false);
					$subpageSimpleEntry->date  = date('Y-m-d G:i:s', $date[0]);
					$subpageSimpleEntry->title = $_POST['SubPageBlogEntry']['title'];
					$subpageSimpleEntry->text = $_POST['SubPageBlogEntry']['text'];
					$subpageSimpleEntry->visibility = $_POST['SubPageBlogEntry']['visibility'];	// TODO: news can not be private
					
					if($subpageSimpleEntry->validate()) {						
						$uploadedFile= CUploadedFile::getInstancesByName('file_name');
						foreach ($uploadedFile as $file) {						
							$tmp_image = new ImageModel;
							$tmp_image->date = $subpageSimpleEntry->date;
						
							$length = 20;
							$chars = array_merge(range(0,9), range('a','z'), range('A','Z'));
							shuffle($chars);
							$RandFileName = implode(array_slice($chars, 0, $length));
							$RandFileName = $blogImagePath.$RandFileName. $file->name;
							$tmp_image->file_name = $RandFileName;
							$tmpUploadedFiles[] = $RandFileName;
							if($tmp_image->validate())
							{
								$fileSaved = $file->saveAs($RandFileName);
								if($fileSaved) {
									if($tmp_image->save()) {						
										$simpleBlogEntryImage = new SimpleBlogImage;
										$simpleBlogEntryImage->subpage_simple_blog_id = $subpageSimpleEntry->subpage_simple_blog_id;
										$simpleBlogEntryImage->img_id = $tmp_image->img_id;
										if($simpleBlogEntryImage->validate()) {
											$simpleBlogEntryImage->save();
										}
									}
								}
								else
									throw new CHttpException('could not upload Image');
						
							}
							else
								throw new CDbException('could not validate the ImageModel');
						}
						
						
						$subpageSimpleEntry->update();
						$transaction->commit();
						$entrySuccessfulUpdated = true;
					}
					else {
						throw new CDbException('Can not validate subpageSimpleEntry Model');
					}
				}
				
				
				
				/*
				 * get simple blog entry images that will be displayed in edit view
				 */
				$blogImages = SimpleBlogImage::model()->findAllByAttributes(
						array('subpage_simple_blog_id' => $subpageSimpleEntry->subpage_simple_blog_id) );
				$bImages = array();
				$imgIds = array();
				foreach ($blogImages as $image) {
					$tmpImage = ImageModel::model()->findByPk($image->img_id);
					if(isset($tmpImage) && isset($tmpImage->file_name) && file_exists($tmpImage->file_name)) {
						$easyImg = new EasyImage($tmpImage->file_name);
						$bImages[] = $easyImg;
						$imgIds[] = $image->img_id;
					}
				}
				
				
				$this->render('editSubPageEntry', array('subPage' => $subPage, 'subPageEntryModel'=> $subpageSimpleEntry,
				'blogImages' => $bImages, 'imgIds' => $imgIds, 'entrySuccessfulUpdated' => $entrySuccessfulUpdated ));
				return;		
			}
			catch (Exception $e) {
				$transaction->rollback();
				
				foreach ($tmpUploadedFiles as $fileName) {
					if(file_exists($fileName)) {
						unlink($fileName);
					}
				}				
				
				$this->redirect(Yii::app()->homeUrl);		// TODO: different redirect
			}
			
			$this->render('editSubPageEntry', array('subPage' => $subPage, 'subPageEntryModel'=>$subPageEntry_id));
			return;
	
		}
		$this->redirect(Yii::app()->homeUrl);
	}
	
		
	public function actionSubPageEditOverview() {
		
	$isUser = (!Yii::app()->user->getIsGuest());
	$access = Yii::app()->user->checkAccess('club_manager');
	if($isUser && $access) {		
// 		$newSubPage = new SubPage;
		$clubID = Yii::app()->user->getState('club_id');		
		$subPages = SubPage::model()->findAllByAttributes(array('club_id' => $clubID), array('order'=>'order_id ASC'));
		
		$this->render('editSubPageOverview', array(/*'newSubPage' => $newSubPage, */'subPages' => $subPages));
		return;
	}
	$this->redirect(Yii::app()->homeUrl);
	
	}
	
	
	
	public function actionRearrangeSubPages() {
	
		$isUser = (!Yii::app()->user->getIsGuest());
		$access = Yii::app()->user->checkAccess('club_manager');
		if($isUser && $access) {
		
			$club_id = Yii::app()->user->getState('club_id');
// 			$u_id = Yii::app()->user->id;
			if (Yii::app()->request->isAjaxRequest) {
					
				$this->layout=false;
				header('Content-type: application/json');
		
				$postData = file_get_contents('php://input');
				$rankArray = CJSON::decode($postData, true);
				$err = '';
		
				if(isset($rankArray['order'])) {
						
					$ord = $rankArray['order'];
						
					$allUpdated = true;
					// TODO: transaction and rollback if one subPage order could not be saved
						
					$transaction = Yii::app()->db->beginTransaction();
					try
					{
						foreach($ord as $sbId => $sbOrder) {
		
							$subPageModel = SubPage::model()->findByPk($sbId);
							if($subPageModel) {
								if($subPageModel->club_id == $club_id) {
									$subPageModel->order_id = $sbOrder;
									if($subPageModel->validate('order_id')) {
										$updated = $subPageModel->update('order_id');
										if(!$updated) {
											throw new CDbException('can save subPage order. Update error');
										}
									}
									else {
										throw new CDbException('can save subPage order. Validation error');
									}
								}
								else {
									throw new CDbException('can save subPage order. Wrong club id: ' . $club_id);
								}
							}
							else {
								throw new CDbException('can save subPage order. No subPage with id: ' .$sbId. ' found.');
							}
						}
		
						$transaction->commit();
					}
					catch (Exception $e) {
						$transaction->rollback();
		
						echo CJSON::encode( array('valid' => false, 'msg' => $err));
						return;
					}
						
					echo CJSON::encode( array('valid' => true));
					return;
				}
		
				echo CJSON::encode( array('valid' => false, 'msg' => 'no data send.'));
				return;
			}
		}
		
		
		$this->redirect(Yii::app()->homeUrl);
		return;
	}
}

?>