<?php

class TeamController extends Controller
{
	
	/**
	 * This is the default 'index' action that is invoked
	 * when an action is not explicitly requested by users.
	 */
	public function actionIndex()
	{
		// renders the view file 'protected/views/site/index.php'
		// using the default layout 'protected/views/layouts/main.php'
		$this->render('error');
	}
	
	/**
	 * This is the action to handle external exceptions.
	 */
	public function actionError()
	{
		if($error=Yii::app()->errorHandler->error)
		{
			if(Yii::app()->request->isAjaxRequest)
				echo $error['message'];
			else
				$this->render('error', $error);
		}
	}

	/**
	 * deletes a player from a given team.
	 * the player that should be deleted and the team he should
	 * be deleted from must be given via ajax request (player_id; team_id).
	 * If the player that triggers the delete operation does not belong to 
	 * the same club as the player that souhld be deleted, the operation
	 * will be aborded.
	 * 
	 * @throws CHttpException
	 */
	public function actionDeletePlayer($player_id, $team_id) {
		
		$access = Yii::app()->user->checkAccess('club_manager');	// TODO: use team_manager role later
		$isUser = !Yii::app()->user->getIsGuest();
		if($isUser && $access) {
			$clubID = Yii::app()->user->getState('club_id');
			$userID = Yii::app()->user->id;
				
			$transaction = Yii::app()->db->beginTransaction();
			try
			{						
				if(!isset($player_id) || !isset($team_id)) {
					throw new CHttpException('cannot delete player. No team or player id given');
				}				
				$delPlayerID = $player_id;
				$teamID = $team_id;				
				
				/*
				 * check if player that should be deleted is a member of the desired team
				 */
				$hasTeam = HasTeams::model()->findByPk(array('team_id' => $teamID, 'u_id' => $delPlayerID));
				if(!isset($hasTeam)) {
					throw new CDbException('cannot delete player. Player ' .$delPlayerID.' does not belong to team ' .$teamID);							
				}
																
				/*
				 * check if the player that should be deleted belongs to the same club as the 
				 * user that triggered the request.
				*/
				$hasClub = HasClubs::model()->findByPk(array('club_id' => $clubID, 'u_id' => $delPlayerID));
				if(!isset($hasClub)) {
					throw new CDbException('cannot delete player. Player ' .$delPlayerID.' does not belong to club ' .$clubID);							
				}
				
				/*
				 * check if the team the player should be deleted from belongs to the same club
				 * as the user who triggerd the command.
				 */
				$team = Team::model()->findByPk($teamID);
				if(!isset($team) || $team->club_id != $clubID) {
					throw new CDbException('cannot delete player. Team ' .$teamID.' does not belong to club ' 
							.$clubID .' as the player that soulh be deleted: ' . $delPlayerID);
				}
				
				if(!$hasTeam->delete()) {
					throw new CDbException('cannot delete player. Deleting from database failed');
				}
				
				$transaction->commit();	
			}
			catch (Exception $e) {
				$transaction->rollback();
				
// 				throw new CException($e->getMessage());
			}
			
		}
		
		$this->redirect($this->createUrl('team/editTeam/team_id/'.$team_id));
		return;
	}
	
	
	public function actionDeleteTeam($team_id) {
		
		$access = Yii::app()->user->checkAccess('club_manager');	// TODO: use team_manager role later
		$isUser = !Yii::app()->user->getIsGuest();
		if($isUser && $access) {
			$clubID = Yii::app()->user->getState('club_id');
			$userID = Yii::app()->user->id;
			
			$transaction = Yii::app()->db->beginTransaction();
			try
			{
				/*
				 * team exists
				 */
				$team = Team::model()->findByPk($team_id);
				if(!isset($team)) {
					throw new CDbException('cannot delete team. team ' . $team_id .' does not exist.');
				}
				
				/*
				 * user belongs to the same club, as the team he wants to delete
				*/
				if($team->club_id != $clubID) {
					throw new CDbException('cannot delete team. user belongs to club '.$clubID.', 
							but team ' . $team_id .' belongs to club ' .$team->club_id);
				}
				
				if(!$team->delete()) {
					throw new CDbException('cannot delete team. Deleting from database failed');
				}
				
				$transaction->commit();
			}
			catch (Exception $e) {
				$transaction->rollback();
			
				// 				throw new CException($e->getMessage());
			}			
		}
		
		$this->redirect($this->createUrl('team/teamsEditOverview'));
		return;
	}
	
	/**
	 * 
	 * @throws CDbException
	 * @throws CHttpException
	 */
	public function actionAssignTeam() {
		
		if(Yii::app()->request->isAjaxRequest) {
			
			
			$this->layout=false;
			header('Content-type: application/json');
		
			$postData = file_get_contents('php://input');
			$postArray = CJSON::decode($postData, true);
		
			$transaction = Yii::app()->db->beginTransaction();
			try
			{
			
				if(isset($postArray['player_id']) && isset($postArray['checkValues'])) {
					// TODO: assert: player_id==int &&& checkValues == array(team_id => bool)
					
					$access = Yii::app()->user->checkAccess('club_manager');
					if(!Yii::app()->user->getIsGuest() && $access) {
						$clubID = Yii::app()->user->getState('club_id');
						$u_id = Yii::app()->user->id;
						
						$player_id = $postArray['player_id'];
						$checkValues = $postArray['checkValues'];
						/*
						 * check if the player for whom clubs should be (un)assigned
						 * belongs to the same club as the user that triggers the action
						 */						
						$hasClub = HasClubs::model()->findByPk(array('u_id' => $player_id, 'club_id' => $clubID));
						if( isset($hasClub) && $hasClub->activated) {
							/*
							 * check if the player for whom clubs should be (un)assigned
							* is activated within the system
							*/
							$player = User::model()->findByPk($player_id);
							if(isset($player) && $player->activated) {
																
								$clubTeams = Team::model()->findAllByAttributes(array('club_id' => $clubID));
								if(isset($clubTeams)) {
									foreach ($clubTeams as $clubTeam) {
										if(isset($checkValues[$clubTeam->team_id])) {
											
											$hasTeam = HasTeams::model()->findByPk(array('u_id' => $player_id, 'team_id' => $clubTeam->team_id));																							
											if($checkValues[$clubTeam->team_id] == true) {
												if(!isset($hasTeam)) {
													$newHasTeam = new HasTeams;
													$newHasTeam->team_id = $clubTeam->team_id;
													$newHasTeam->u_id = $player_id;
													$newHasTeam->player_rank = 100;
													$newHasTeam->reserve = 0;
													
													if($newHasTeam->validate()) {
														$newHasTeam->save();
													}
													else {
														throw new CDbException(403, 'Validation error: team_id: ' .$newHasTeam->team_id  . '; u_id: ' .$newHasTeam->u_id);
													}
												}
											}
											else {
												if(isset($hasTeam)) {
													if(!$hasTeam->delete()) {
														throw new CDbException('cannot remove player '.$player_id.' from team '.$newHasTeam->team_id.'. Deleting from database failed');
													}
												}	
											}
										}										
									}
								}
								else {
									throw new CHttpException('club '.$clubID.' has no teams.');
								}

								$transaction->commit();
								echo CJSON::encode( array('valid' => true, 'player' => $player_id));
								return;
							}
							throw new CDbException(403, 'user '.$player_id.' does not exist or ist not activated within the system.');
						}
						throw new CDbException(403, 'user '.$player_id.' not activated for club: ' . $clubID );
					}
					throw new CDbException(403, 'not activated user tries to trigger action');
				}
				throw new CHttpException('invalid ajax request.');
			}
			catch (Exception $e) {
				$transaction->rollback();
			}			
			
			echo CJSON::encode( array('valid' => false, 'err' => '' ));
			return;
		}
		
		$this->redirect(Yii::app()->homeUrl);
		return;
	}
	
	public function actionAssignTeamOverview() {
		
		$access = Yii::app()->user->checkAccess('club_manager');
		if(!Yii::app()->user->getIsGuest() && $access) {
			Yii::import('application.controllers.ClubController');
			$dummyController = new ClubController('dummy_ClubController');
			$players = $dummyController->getAllPlayers();
			$data = array();
			foreach ($players as $player) {
				$teams = $dummyController->getTeams($player->u_id);
				$data[] = array('player' => $player, 'teams' => $teams);
			}
				
			$allTeams = $dummyController->getAllTeams();
			$this->render('assignTeamOverview', array('data' => $data, 'allTeams' => $allTeams));
			return;
		}
		
		$this->redirect(Yii::app()->homeUrl);
	}
	
	/**
	 * 
	 * @param unknown $team_id
	 * @throws CDbException
	 * @throws CHttpException
	 */
	public function actionAddPlayer($team_id) {
		
		$errorMsg = '';
		$access = Yii::app()->user->checkAccess('club_manager');	// TODO: use team_manager role later
		$isUser = !Yii::app()->user->getIsGuest();
		if($isUser && $access) {
			$clubID = Yii::app()->user->getState('club_id');
			
			
			$transaction = Yii::app()->db->beginTransaction();
			try
			{
				$teamModel = Team::model()->findByPk($team_id);
				if($teamModel && $teamModel->club_id == $clubID) {		
					if(Yii::app()->request->isAjaxRequest) {
						
						$this->layout=false;
						header('Content-type: application/json');
						
						$postData = file_get_contents('php://input');
						$postArray = CJSON::decode($postData, true);
						
						if(isset($postArray['player_id'])) {		
							$u_id = $postArray['player_id'];
													
							$player = User::model()->findByPk($u_id);
							if($player) {								
								// check if player's club and team club are the same
								$hasClubs = HasClubs::model()->findAllByAttributes(array('club_id' => $clubID, 'u_id' => $u_id));
								if(empty($hasClubs)){
									throw new CDbException('player does not belong to given club.');
								}
								$clubHasTeams = Team::model()->findAllByAttributes(array('club_id' => $clubID, 'team_id' => $team_id));
								if(empty($clubHasTeams)){
									throw new CDbException('player does not belong to given club.');
								}
								
								
								// check if player already belongs to team
								$hasTeams = HasTeams::model()->findAllByAttributes(array('team_id' => $team_id, 'u_id' => $u_id));
								if(empty($hasTeams)) {
									$hasTeams = new HasTeams;
									$hasTeams->player_rank = 100;
									$hasTeams->team_id = $team_id;
									$hasTeams->u_id = $u_id;
									
									if($hasTeams->validate()) {
										$hasTeams->save();
										
										$transaction->commit();
										
										echo CJSON::encode( array('valid' => true, 
												'player_id' => $u_id, 'player_name' => $player->name, 
												'player_edit_link' => '<a href="'.$this->createUrl('user/editProfile', array('user' => $u_id)).'">',
												'player_prename' => $player->prename, 'base_url' => Yii::app()->request->baseUrl));
										return;
									}
									throw new CDbException('can not validate hasTeam relation.');
								}
								throw new CDbException(403, 'player already belongs to given team.');
																
							} 		
							throw new CDbException('player id already exists.');
						}																		
						throw new CDbException('no player stated in ajax request.');
					}	
					throw new CHttpException('no ajax request arrived.');	
				}
				throw new CDbException('user does not beloong to given club, or the choosen team does not exists.');
			}
			catch (Exception $e) {
				$transaction->rollback();
			}
		}
		
		echo CJSON::encode( array('valid' => false, 'msg' => '' ));
		return;
	}
	
	
	/**
	 * 
	 * @param unknown $team_id id of the team you want to edit
	 */
	public function actionEditTeam($team_id) {				
		
		if(isset($team_id)) {
		
			$isUser = (!Yii::app()->user->getIsGuest());
			$access = Yii::app()->user->checkAccess('club_manager');	// TODO: use team_manager role later
			if($isUser && $access) {
								
				$clubID = Yii::app()->user->getState('club_id');
				$captain = '';
				
				$teamModel = Team::model()->findByPk($team_id);		
				if($teamModel && $teamModel->club_id == $clubID) {
					
					$teamPlayers = HasTeams::model()->findAllByAttributes(array('team_id' => $teamModel->team_id), 
							array('order'=>'player_rank ASC'));
					$players = array();
					foreach ($teamPlayers as $teamPlayer) {
						$player = User::model()->findByPk($teamPlayer->u_id);
						$players[] = $player;					
					}
					
					// take image
					$teamEasyImg = new EasyImage(self::$teamImagePath.'dummy_team_image.png');
					if(isset($teamModel->img_id)) {
						$teamImage = ImageModel::model()->findByPk($teamModel->img_id);
						if($teamImage) {
							if(isset($teamImage->file_name) && file_exists($teamImage->file_name)) {
								$teamEasyImg = new EasyImage($teamImage->file_name);
							}							
						}
					}
					$teamImage = $teamEasyImg;						
					
					// take team captain
					$captain_id= $teamModel->captain;
					$captainUserModel = User::model()->findByPk($captain_id);
					if($captainUserModel) {
						$captain = $captainUserModel-> prename . ' ' .$captainUserModel->name;
					}
					
					
					/*
					 * alter data
					 */
					if(Yii::app()->request->isAjaxRequest) {
						
						$this->layout=false;
						header('Content-type: application/json');
						
						$postData = file_get_contents('php://input');
						$rankArray = CJSON::decode($postData, true);
						
						$allUpdated = true; // TODO: transaction
						if(isset($rankArray['order'])) {
							
							foreach($rankArray['order'] as $playerId => $playerRank) {
								$hasTeam = HasTeams::model()->findAllByAttributes(array('u_id' => $playerId,
										'team_id' => $team_id));
								// TODO: assert(count($hasTeam) == 1)
								$hasTeam = $hasTeam[0];
								if($hasTeam) {
	 								$hasTeam->player_rank = $playerRank;

									if($hasTeam->validate()) {
	 									$updated = HasTeams::model()->updateAll(array('player_rank' => $playerRank),
	 											'u_id='.$playerId.' AND team_id='.$team_id);
										if(!$updated) {
											$allUpdated = false;
										}
									}
									else {
										$allUpdated = false;
									}
	
								}
							}
						}		
						
						
						
						if(isset($rankArray['team_name'])) {												
							$teamModel->team_name = $rankArray['team_name'];
						}
						
						if(isset($rankArray['captain'])) {
							
							if($rankArray['captain'] > 0) {
								$tmp_user_model = User::model()->findByPk($rankArray['captain']);
								if(isset($tmp_user_model)) {
									$clubModel = HasClubs::model()->findAllByAttributes(array('club_id' => $clubID, 'u_id' => $rankArray['captain']));
									if(!empty($clubModel)) {
										$teamModel->captain = $rankArray['captain'];
									}	
								}								
							}
						}
						
						if(isset($rankArray['image_text'])) {
							$teamModel->img_text = $rankArray['image_text'];
						}
						
						
						
						$valid = $teamModel->validate();
						$teamUpdated = false;
						if($valid) {
							$teamUpdated = $teamModel->update();
						}
						
						if($allUpdated && $teamUpdated) {
							echo CJSON::encode( array('valid' => true));
							return;
						}
						else {
							echo CJSON::encode( array('valid' => false, 'msg' => 'fehler'));
							return;
						}
						
					}	
					
					// handling image upload				
					$uploadedFile= CUploadedFile::getInstancesByName('file_name');
					if(!empty($uploadedFile)) {
						$file = $uploadedFile[0];
						$tmp_image = new ImageModel;
						$date = CTimestamp::getDate(false, false, false);
						$tmp_image->date = date('Y-m-d G:i:s', $date[0]);
						
						$length = 20;
						$chars = array_merge(range(0,9), range('a','z'), range('A','Z'));
						shuffle($chars);
						$RandFileName = implode(array_slice($chars, 0, $length));
						$RandFileName = self::$teamImagePath.$RandFileName. $file->name;
						$tmp_image->file_name = $RandFileName;
						
						if($tmp_image->validate()) {
							$fileSaved = $file->saveAs($RandFileName);
							if($fileSaved) {
								
								$transaction = Yii::app()->db->beginTransaction();
								try
								{
									$imgSaved = $tmp_image->save();
									if($imgSaved) {
										$oldTeamImage = ImageModel::model()->findByPk($teamModel->img_id);
										$teamModel->img_id = $tmp_image->img_id;
										if($teamModel->validate()) {
											$teamModel->update();
												
											// delete old image:
											if($oldTeamImage) {
												if(isset($oldTeamImage->file_name)) {
													unlink($oldTeamImage->file_name);
													$oldTeamImage-> delete();
												}											
											}
												
											$transaction->commit();											
											$teamImage = new EasyImage($tmp_image->file_name);
										}
									}							
								}
								catch(Exception $e)
								{
									$transaction->rollback();							
								}
							}
						}
					}
					
					
					$this->render('editTeam', array('teamModel' => $teamModel, 'captain' => $captain, 'teamImage' => $teamImage, 'players' => $players));
					return;							
				}
				else {
					$this->actionTeamsEditOverview();
					return;
				}
		
			}
		}
		
		$this->redirect(Yii::app()->homeUrl);
	}
	
	
	/**
	 * 
	 */
	public function actionTeamsEditOverview() {
		
		$isUser = (!Yii::app()->user->getIsGuest());
		$access = Yii::app()->user->checkAccess('club_manager');	// TODO: use team_manager role later
		if($isUser && $access) {		
			$newTeam = new Team;
			$clubID = Yii::app()->user->getState('club_id');		
			$teams = Team::model()->findAllByAttributes(array('club_id' => $clubID), array('order'=>'team_rank ASC'));
			
			$this->render('editTeamsOverview', array('newTeam' => $newTeam, 'teams' => $teams));
			return;
		}

		$this->redirect(Yii::app()->homeUrl);
	}
	
	/**
	 * 
	 */
	public function actionCreateTeam() {
		
		$isUser = (!Yii::app()->user->getIsGuest());
		$access = Yii::app()->user->checkAccess('club_manager');
		if($isUser && $access) {
			
			$teamModel = new Team;
			$teamData  = false;
			$u_id = Yii::app()->user->id;
				
				
			if (Yii::app()->request->isAjaxRequest) {
			
				if(isset($_POST['Team'])) {
					$this->layout=false;
					header('Content-type: application/json');
					$teamModel->team_name = $_POST['Team']['team_name'];
						
					$validTeam = $teamModel->validate();
					if($validTeam) {
						$club_id = Yii::app()->user->getState('club_id');
						$teamModel->club_id = $club_id;
			
						/*
						 * check if user really belongs to the given club
						*/
						$hasClub = HasClubs::model()->exists('u_id='.$u_id.'AND club_id='.($club_id));
						if($hasClub) {
							$teamModel->save();
						}
					}
					// TODO:		$teamModel->save(); is not used at the moment
					echo CJSON::encode(array('valid' => $validTeam, 'teamModel' => $teamModel));
					return;
				}
			
			}	

			$this->render('clubAdministration', array('teamModel' => $teamModel, 'teamData' => $teamData));
			return;
		}
		
		$this->redirect(Yii::app()->homeUrl);
		return;		
	}
	
		
	/**
	 * 
	 */
	public function actionArrangeTeams() {
				
		$isUser = (!Yii::app()->user->getIsGuest());
		$access = Yii::app()->user->checkAccess('club_manager');
		if($isUser && $access) {

			$club_id = Yii::app()->user->getState('club_id');
			$u_id = Yii::app()->user->id;
			if (Yii::app()->request->isAjaxRequest) {				
								 
				$this->layout=false;
				header('Content-type: application/json');
				
				$postData = file_get_contents('php://input');
				$rankArray = CJSON::decode($postData, true);				
				$err = '';
				
				if(isset($rankArray['order'])) {	
					
					$ord = $rankArray['order'];
					
					$allUpdated = true; 
					// TODO: transaction and rollback if one team order could not be saved
					
					$transaction = Yii::app()->db->beginTransaction();
					try
					{
						foreach($ord as $teamId => $teamRank) {					
						
							$teamModel = Team::model()->findByPk($teamId);
							if($teamModel) {
								if($teamModel->club_id == $club_id) {
									$teamModel->team_rank = $teamRank;
									if($teamModel->validate('team_rank')) {
										$updated = $teamModel->update('team_rank');
										if(!$updated) {
											throw new CDbException('can save team order. Update error');
										}
									}
									else {
										throw new CDbException('can save team order. Validation error');
									}
								}
								else {
									throw new CDbException('can save team order. Wrong club id: ' . $club_id);
								}
							}
							else {
								throw new CDbException('can save team order. No team with id: ' .$teamId. ' found.');
							}
						}
						
						$transaction->commit();
					}
					catch (Exception $e) {
						$transaction->rollback();
						
						echo CJSON::encode( array('valid' => false, 'msg' => $err));
						return;
					}					
					
					echo CJSON::encode( array('valid' => true));
					return;									
				}
				
				echo CJSON::encode( array('valid' => false, 'msg' => 'no data send.'));
				return;								
			}
		}
		
		
		$this->redirect(Yii::app()->homeUrl);
		return;
	}
	
	
	
	
	/**
	 * returns all players that belong to the current club and
	 * their prename or name contain a given string, stated by $_GET['term'].
	 * If the string contains several words (devided by ' ') for all
	 * these words are checked against 'name' and 'prename' DB-column. If any
	 * of these words is a substring of 'name' or 'prename' entry, the corresponding
	 * player ist returned as json object. 
	 * 
	 * @return JSON object as array of arrays: 
	 * {"label":"prename name","value":"prename name","id":u_id} with prename, name
	 * and u_id from database. Empty array if no etries were found.
	 */
	public function actionGetPlayers() {
		
		$arr = array(); 
		
		$isUser = (!Yii::app()->user->getIsGuest());
		$access = Yii::app()->user->checkAccess('club_manager');	// TODO: use another role later ??
		if($isUser && $access) {
			if(isset($_GET['term'])) {
				
				$searchStrings = explode(" ", $_GET['term']); 
				foreach($searchStrings as $searchString) {
					$match = addcslashes($searchString, '%_'); // escape LIKE's special characters
					$q = new CDbCriteria( array(
							'condition' => "prename ILIKE :match",         // searching in cloumn 'prename'
							'params'    => array(':match' => "%$match%")  // Aha! Wildcards go here
					));
					$q->addSearchCondition('name', $match, true, 'OR', 'ILIKE');	
				}
				
				$club_id = Yii::app()->user->getState('club_id');
				$players = User::model()->findAll($q);
				foreach($players as $player)
				{		
					$u_id = $player->u_id;
					$isActivated = $player->activated;
					$hasClubs = HasClubs::model()->findAllByAttributes(array('club_id' => $club_id, 'u_id' => $u_id));
					if(!empty($hasClubs) && $hasClubs[0]->activated && $isActivated) {
												
						$arr[] = array(
								'label'=>$player->prename . " " . $player->name,  // label for dropdown list
								'value'=>$player->prename . " " . $player->name,  // value for input field
								'id'=>$player->u_id,            // return value from autocomplete
						);						
					}
				}
			}
		}
		
		echo CJSON::encode($arr);	// no access to players --> return empty list
	}
	
	
	public function actionTest() {
		
		$this->layout=false;
		header('Content-type: application/json');
		
		echo CJSON::encode( array('valid' => true));
		return;		// TODO: del
	}
	
	
	/**
	 * shows all teams that belong to a given club.
	 * If no club is stated, the logged-in user's club
	 * is displayed.
	 */
	public function actionShowTeams($clubId=Null, $clubUrl=Null) {
		
		$clubID = $this->getClubId($clubId, $clubUrl);
		
		if(!isset($clubID) || $clubID <= 0) {
			throw new CException('Error: can not find team');
		}

		
		/*
		 * get teams of given club
		 */
		$teams = Team::model()->findAllByAttributes(array('club_id' => $clubID), array('order'=>'team_rank ASC'));
		
		$teamPaths = array();
		$scaleDirs = array();
		$teamPlayers = array();
		$teamImages = Null;
		foreach ($teams as $team) {
						
			//take not reserved players
			$players = HasTeams::model()->findAllByAttributes(array('team_id' => $team->team_id, 'reserve' => false), 
					array('order'=>'player_rank ASC', 'limit' => 6, 'offset' => 0));
			$playersArray = array();
			foreach ($players as $player) {				
				$tmpPlayer = User::model()->findByPk($player->u_id);
				if(isset($tmpPlayer)) {
					$playersArray[] = $tmpPlayer;
				}
			}
 			$teamPlayers[$team->team_id] = $playersArray;
			
			// take team image
 			$teamImages[$team->team_id] = $easyImg = new EasyImage(self::$teamImagePath.'dummy_team_image.png');
			if(isset($team->img_id)) {
				$teamImage = ImageModel::model()->findByPk($team->img_id);
				if($teamImage) {
					if(isset($teamImage->file_name) && file_exists($teamImage->file_name)) {
						$easyImg = new EasyImage($teamImage->file_name);
						$teamImages[$team->team_id] = $easyImg;
					}			
				}
			}
			
		}
		
		$this->render('showTeams', array('teams' => $teams, 'teamImages' => $teamImages, 'teamPlayers' => $teamPlayers));
		return;
	}
	
	/**
	 * 
	 * @param integer $teamId
	 */
	public function actionShowTeam($teamId=Null) {
		
		if(isset($teamId)) {
			
			$teamModel = Team::model()->findByPk($teamId);
			$captain = '';
			if($teamModel) {
				
				// take team captain
				$captain_id= $teamModel->captain;
				$captainUserModel = User::model()->findByPk($captain_id);
				if($captainUserModel) {
					$captain = $captainUserModel-> prename . ' ' .$captainUserModel->name;
				}
				
				// take image
				$easyImg = new EasyImage(self::$teamImagePath.'dummy_team_image.png');
				if(isset($teamModel->img_id)) {
					$teamImage = ImageModel::model()->findByPk($teamModel->img_id);
					if($teamImage) {
						if(isset($teamImage->file_name) && file_exists($teamImage->file_name)) {
							$easyImg = new EasyImage($teamImage->file_name);
						}						
					}
				}				
				$teamImage = $easyImg;

				
				// take players
				$players = HasTeams::model()->findAllByAttributes(array('team_id' => $teamId), array('order'=>'player_rank ASC'));
				$playersArray = array();
				$playerImages = array();
				foreach ($players as $player) {
					$tmpPlayer = User::model()->findByPk($player->u_id);
					if(isset($tmpPlayer)) {
						$playersArray[] = $tmpPlayer;
						
						// take player image
						$pImg = new EasyImage(self::$playerImagePath.'dummy_player_image.png');
						$pMainProp = UserMainProperties::model()->findByPk($player->u_id);
						if(isset($pMainProp)) {
							$pImgModel = ImageModel::model()->findByPk($pMainProp->img_id);
							if($pImgModel) {
								if(isset($pImgModel->file_name) && file_exists($pImgModel->file_name)) {
									$pImg = new EasyImage($pImgModel->file_name);
								}								
							}							
						} 
						$playerImages[$player->u_id] = $pImg;
					}
				}
				$players = $playersArray;				
			}
			
			
			
			
			$this->render('showTeam', array('teamModel' => $teamModel, 'captain' => $captain, 'teamImage' => $teamImage, 
					'players' => $players, 'playerImages' => $playerImages));
			return;
		}
		
		$this->redirect(Yii::app()->homeUrl);
	}
	
}
?>