<?php

class UserController extends Controller
{
		
	
	/**
	 * This is the default 'index' action that is invoked
	 * when an action is not explicitly requested by users.
	 */
	public function actionIndex()
	{
		// renders the view file 'protected/views/site/index.php'
		// using the default layout 'protected/views/layouts/main.php'
		$this->render('index');
	}
	
	/**
	 * This is the action to handle external exceptions.
	 */
	public function actionError()
	{
		if($error=Yii::app()->errorHandler->error)
		{
			if(Yii::app()->request->isAjaxRequest)
				echo $error['message'];
			else
				$this->render('error', $error);
		}
	}
	

	
	
	
	
	
	/**
	 *
	 * @param type $userId
	 */
	public function actionShowUserProfile($u_id) {
	
		$userModel = User::model()->findByPk($u_id);
	
		if ($userModel != Null) {			
			$userModel->password = Null;
			 
			//
			// determinel if the user has a differnt club
			// than the user that should be shown
			// 
			$currUser = Yii::app()->user->id;
			$currUserClubs = HasClubs::model()->findAllByAttributes(array('u_id' => $currUser));
			$userClubs = HasClubs::model()->findAllByAttributes(array('u_id' => $u_id));
			$sameClub = false;
			foreach ($currUserClubs as $club1) {
				foreach ($userClubs as $club2) {
					if($club1->club_id == $club2->club_id) {
						$sameClub = true;
						break;
					}
				}
			}
			
			if(!$sameClub && isset($userModel->email) && $userModel->validate(array('email')) ) {
				$userModel->email = Null;
			}
			
			$emailModels = array();
			$tmpEmailModels =  UserEmail::model()->findAllByAttributes(array('u_id' => $u_id));
			foreach ($tmpEmailModels as $mailModel) {
				if($mailModel->validate()) {
					if($mailModel->visibility == Visibility::_PUBLIC || 
						(($mailModel->visibility == Visibility::_CLUB) && $sameClub) ||
				        (($mailModel->visibility == Visibility::_PRIVATE) && ($currUser==$u_id)) ) {
						$emailModels[] = $mailModel;
					}
				}
			}
			
			$addressModels = array();
			$tmpAddressModels =  UserAddress::model()->findAllByAttributes(array('u_id' => $u_id));
			foreach ($tmpAddressModels as $addressModel) {
				if($addressModel->validate()) {
					if($addressModel->visibility == Visibility::_PUBLIC ||
					(($addressModel->visibility == Visibility::_CLUB) && $sameClub) ||
				    (($addressModel->visibility == Visibility::_PRIVATE) && ($currUser==$u_id)) ) {
						$addressModels[] = $addressModel;
					}
				}
			}						
						
			$phoneModels = array();
			$tmpPhoneModels =  UserPhone::model()->findAllByAttributes(array('u_id' => $u_id));
			foreach ($tmpPhoneModels as $phoneModel) {
				if($phoneModel->validate() && $phoneModel->phone!='') {
					if($phoneModel->visibility == Visibility::_PUBLIC ||
					(($phoneModel->visibility == Visibility::_CLUB) && $sameClub) || 
					(($phoneModel->visibility == Visibility::_PRIVATE) && ($currUser==$u_id)) ) {
						$phoneModels[] = $phoneModel;
					}
				}
			}
			
			$mainPropertiesModels =  UserMainProperties::model()->findByPk($u_id);
			
			$ttPropertiesModels = TableTennisProperties::model()->findByPk($u_id);
			// TODO: add tt properties image if availabe (similar to image below)
			
			$pImg = new EasyImage(self::$playerImagePath.'dummy_player_image.png');
			if(isset($mainPropertiesModels)) {
				$pImgModel = ImageModel::model()->findByPk($mainPropertiesModels->img_id);
				if($pImgModel) {
					if(isset($pImgModel->file_name) && file_exists($pImgModel->file_name) ) {
						$pImg = new EasyImage($pImgModel->file_name);
					}
				}
			}
			
			
			$ttScoreServiceTTS = TableTennisScoreServiceTts::model()->findByPk($u_id);
			if(isset($mainPropertiesModels)) {
				
			}
			
			
			$this->render('showUserProfile', array('userModel' => $userModel, 'emailModels' => $emailModels, 'addressModels' => $addressModels,
					'mainPropertiesModels' => $mainPropertiesModels, 'ttPropertiesModels' => $ttPropertiesModels, 'ttScoreServiceTTS' => $ttScoreServiceTTS,
					'phoneModels' => $phoneModels, 'pImg' => $pImg, 'userExists' => true));
			
			return;
		}
		
		$this->redirect(Yii::app()->homeUrl);
	}
	
	
	public function actionDeleteUser($u_id) {
		
		// TODO
		//$this->render('index');
	}
	
	/**
	 *
	 */
	public function actionEditProfile($user=Null) {
								
		if(!Yii::app()->user->getIsGuest()) {
	
			$currClub = Yii::app()->user->getState('club_id');	

			$u_id = Yii::app()->user->id;
			if($user && $user != $u_id) {
				
				// check if user that should be edited belongs to the same club the 
				// as user who wants to edit (curent logged in club of the editing user).
				$sameClub = HasClubs::model()->findByPk(array('u_id' => $user, 'club_id' => $currClub));
				
				// check if the editing user is a club manager
				$access = Yii::app()->user->checkAccess('club_manager');
				
				
				if($sameClub && $access) {
					$u_id = $user;
				}
				else {
					$this->redirect($this->createUrl('news/newsFeed'));
					return;
				}
			}
			
			
			$userModel = User::model()->findByPk($u_id);
			$userModel->password = Null;
	
			//TODO: assert: $userModel != NULL;
	
			$emailModels =  UserEmail::model()->findAllByAttributes(array('u_id' => $u_id));
			if(empty($emailModels)) {
				$emailModels['0'] = new UserEmail;
				$emailModels['0']->u_id = $u_id;
				$emailModels['0']->label = 'privat';
				if($emailModels['0']->validate()) {
					$emailModels['0']->save();
				}
				else {
					throw new CDbException('Fehler beim anfragen/anlegen von Benutzerdaten.');
				}
			}
			$addressModels =  UserAddress::model()->findAllByAttributes(array('u_id' => $u_id));
			if(empty($addressModels)) {
				$addressModels['0'] = new UserAddress;
				$addressModels['0']->u_id = $u_id;
				$addressModels['0']->label = 'privat';
				if($addressModels['0']->validate()) {
					$addressModels['0']->save();
				}
				else {
					throw new CDbException('Fehler beim anfragen/anlegen von Benutzerdaten.');
				}
			}
	
			$mainPropertiesModels =  UserMainProperties::model()->findByPk($u_id);
			if($mainPropertiesModels == NULL) {
				$mainPropertiesModels = new UserMainProperties;
				$mainPropertiesModels->u_id = $u_id;
				$mainPropertiesModels->img_id = Null;
				if($mainPropertiesModels->validate()) {
					$mainPropertiesModels->save();
				}
				else {
					throw new CDbException('Fehler beim anfragen/anlegen von Benutzerdaten.');
				}
			}
			$phoneModels =  UserPhone::model()->findAllByAttributes(array('u_id' => $u_id));
			if(empty($phoneModels)) {
				$phoneModels['0'] = new UserPhone;
				$phoneModels['0']->u_id = $u_id;
				$phoneModels['0']->label = 'privat';
				if($phoneModels['0']->validate()) {
					$phoneModels['0']->save();
				}
				else {
					throw new CDbException('Fehler beim anfragen/anlegen von Benutzerdaten.');
				}
			}

			$ttPropertiesModels = TableTennisProperties::model()->findByPk($u_id);
			if($ttPropertiesModels == NULL) {
				$ttPropertiesModels = new TableTennisProperties;
				$ttPropertiesModels->u_id = $u_id;
				if($ttPropertiesModels->validate()) {
					$ttPropertiesModels->save();
				}
				else {
					throw new CDbException('Fehler beim anfragen/anlegen von Benutzerdaten.');
				}
			}
			
			$playerImageModel = new ImageModel;
			$pImg = new EasyImage(self::$playerImagePath.'dummy_player_image.png');
			// TODO: file_exists(self::$playerImagePath.'dummy_player_image.png')		// everywhere
			if(isset($mainPropertiesModels)) {				
				if(isset($mainPropertiesModels->img_id)) {
					$pImgModel = ImageModel::model()->findByPk($mainPropertiesModels->img_id);
					if($pImgModel) {
						if(isset($pImgModel->file_name) && file_exists($pImgModel->file_name)) {
							$pImg = new EasyImage($pImgModel->file_name);
						}
					}	
				}				
			}
			
	
			$dataUpdated = false;
			$updateErrorMessage = array('noErrors' => true);
	
				/*
				 * 
				* update main user model
				*/
				if(isset($_POST['User'])) {
				
					if(isset($_POST['User'])) {
						$userModel->name=$_POST['User']['name'];
						$userModel->prename=$_POST['User']['prename'];
												
						if($userModel->validate(array('name', 'prename'))) {
							$userModel->update(array('name', 'prename'));
							$dataUpdated = true;
						}
						else {
							echo print_r($userModel->getErrors());
						}
					}
				
				}
	
	
				/*
				* update email addresses
				*/
				if(isset($_POST['UserEmail'])) {
					foreach($emailModels as $i=>$item) {
						if(isset($_POST['UserEmail'][$i])) {
							$item->email=$_POST['UserEmail'][$i]['email'];
							$item->label=$_POST['UserEmail'][$i]['label'];
							$item->visibility = $_POST['UserEmail'][$i]['visibility'];
						}
	
						 if($item->validate()) {
						  	$item->update();
						 }
						 else {
							 $updateErrorMessage = $updateErrorMessage['UserEmail'][$i] = $item->getErrors();
							 $updateErrorMessage['noErrors'] = false;
						 }
					 }
	
		 			$dataUpdated = true;
		 		}
		
		 			/*
		 			* update phone numbers
		 		*/
		 		if(isset($_POST['UserPhone'])) {
		 			foreach($phoneModels as $i=>$item) {
		 				if(isset($_POST['UserPhone'][$i])) {
		 					$item->phone=$_POST['UserPhone'][$i]['phone'];
		 					$item->label=$_POST['UserPhone'][$i]['label'];
		 					$item->visibility = $_POST['UserPhone'][$i]['visibility']; 					
						}
		
						 if($item->validate()) {
						 	$item->update();
						 }
						 else {
							 $updateErrorMessage = $updateErrorMessage['UserPhone'][$i] = $item->getErrors();
							 $updateErrorMessage['noErrors'] = false;
						 }
					 }
		  
				 	$dataUpdated = true;
				 }
		
		
			 /*
			 * update post addresses
			 */
			 if(isset($_POST['UserAddress'])) {
			 foreach($addressModels as $i=>$item) {
				 if(isset($_POST['UserAddress'][$i])) {
				 	$item->label=$_POST['UserAddress'][$i]['label'];
			 		$item->street=$_POST['UserAddress'][$i]['street'];
			 		$item->house_no=$_POST['UserAddress'][$i]['house_no'];
			 		$item->postal_code=$_POST['UserAddress'][$i]['postal_code'];
			 		$item->city=$_POST['UserAddress'][$i]['city'];
			 		$item->visibility = $_POST['UserAddress'][$i]['visibility'];
				 	//$item->country=$_POST['UserAddress'][$i]['country'];
				 }
				
				 if($item->validate()) {
				 	$item->update();
				 }
				 else {
					 $updateErrorMessage = $updateErrorMessage['UserAddress'][$i] = $item->getErrors();
					 $updateErrorMessage['noErrors'] = false;
				 }
			 }
			
			 $dataUpdated = true;
			 }
			
			 /*
			 * update user main properties
			 */
			 $mainPropertiesModels->birthday = date("Y-m-d", strtotime($mainPropertiesModels->birthday));
// 			 echo "date: " . $mainPropertiesModels->birthday;
			 if(isset($_POST['UserMainProperties'])) {
				 $mainPropertiesModels->gender=$_POST['UserMainProperties']['gender'];
				 $mainPropertiesModels->nickname=$_POST['UserMainProperties']['nickname'];
				 $mainPropertiesModels->motto=$_POST['UserMainProperties']['motto'];
				 $mainPropertiesModels->profession=$_POST['UserMainProperties']['profession'];
				 $mainPropertiesModels->website=$_POST['UserMainProperties']['website'];
				 $mainPropertiesModels->birthday=$_POST['UserMainProperties']['birthday'];
			 	if($mainPropertiesModels->validate()) {
			 			$mainPropertiesModels->update();
			 			
			 			$dataUpdated = true;
				 }
				 else {
				 $updateErrorMessage = $updateErrorMessage['UserMainProperties'] = $mainPropertiesModels->getErrors();
				 		$updateErrorMessage['noErrors'] = false;
				 }
			 }
			 
			 
			if(isset($_POST['TableTennisProperties'])) {
				 $ttPropertiesModels->score_service_link=$_POST['TableTennisProperties']['score_service_link'];
				 $ttPropertiesModels->forehand=$_POST['TableTennisProperties']['forehand'];
				 $ttPropertiesModels->backhand=$_POST['TableTennisProperties']['backhand'];
				 $ttPropertiesModels->blade=$_POST['TableTennisProperties']['blade'];
// 				 $ttPropertiesModels->specialty=$_POST['TableTennisProperties']['specialty'];
				 $ttPropertiesModels->right_hander=$_POST['TableTennisProperties']['right_hander'];
// 				 $ttPropertiesModels->shoes=$_POST['TableTennisProperties']['shoes'];
			
			 	if($ttPropertiesModels->validate()) {
			 			$ttPropertiesModels->update();
				 }
				 else {
				 $updateErrorMessage = $updateErrorMessage['TableTennisProperties'] = $ttPropertiesModels->getErrors();
				 		$updateErrorMessage['noErrors'] = false;
				 		
				 		$dataUpdated = true;
				 }
			 }
			 
			 $uploadedFile= CUploadedFile::getInstancesByName('file_name');
			 if(!empty($uploadedFile)) {
			 	echo "Uploaded";
			 	$file = $uploadedFile[0];
			 	$tmp_image = new ImageModel;
			 	$date = CTimestamp::getDate(false, false, false);
			 	$tmp_image->date = date('Y-m-d G:i:s', $date[0]);
			 		
			 	$length = 20;
			 	$chars = array_merge(range(0,9), range('a','z'), range('A','Z'));
			 	shuffle($chars);
			 	$RandFileName = implode(array_slice($chars, 0, $length));
			 	$RandFileName = self::$playerImagePath.$RandFileName. $file->name;
			 	$tmp_image->file_name = $RandFileName;
			 		
			 	if($tmp_image->validate()) {
			 		$fileSaved = $file->saveAs($RandFileName);
			 		if($fileSaved) {
			 				
			 			$transaction = Yii::app()->db->beginTransaction();
			 			try
			 			{
			 				//$tmp_image->date = Null; // for testing transactions; uncomment in production mode
			 				$imgSaved = $tmp_image->save();
			 				if($imgSaved) {
			 					
		 						$oldPlayerImage = ImageModel::model()->findByPk($mainPropertiesModels->img_id);
		 						$mainPropertiesModels->img_id = $tmp_image->img_id;
		 						if($mainPropertiesModels->validate()) {
		 							if(!$mainPropertiesModels->update())
		 								throw new CDbException('Daten konnten nicht gespeichert werden.');
		 								
		 							// delete old image:
		 							if($oldPlayerImage) {
		 								if(isset($oldPlayerImage->file_name)) {
		 									if(file_exists($oldPlayerImage->file_name)) {
		 										unlink($oldPlayerImage->file_name);
		 									}	
		 									// no exception needed as else case.
		 									// e.g filename somehow changed on disc --> disc->file_name != db->file_name
		 									// ==> throwing exception prevents changing the image,
		 									// because a rollback is executed. 
		 									// ==> if(disc->file_name != db->file_name) : add new foto to disc
		 									// old picture simply stays unchanged

		 									
		 									if(!$oldPlayerImage-> delete())
		 										throw new CDbException('Daten konnten nicht gespeichert werden.');
		 								}		 								
		 							}
		 								
		 							$transaction->commit();
		 							
		 							$pImg = new EasyImage($tmp_image->file_name);
		 						}	
			 					else 
			 						throw new CDbException('Daten konnten nicht gespeichert werden.');
			 				}	
			 				else 
			 					throw new CDbException('Daten konnten nicht gespeichert werden.');			 				
			 				
			 			}
			 			catch(Exception $e)
			 			{
			 				$dataUpdated = false;
			 				$updateErrorMessage['noErrors'] = false;
			 				$transaction->rollback();			 				
			 			}
			 		}
			 	}
			 }
			 
			 if($dataUpdated) {
				 $this->render('editProfile', array('userModel' => $userModel, 'emailModels' => $emailModels, 'addressModels' => $addressModels,
				 'mainPropertiesModels' => $mainPropertiesModels, 'ttPropertiesModels' => $ttPropertiesModels, 'phoneModels' => $phoneModels, 'pImg' => $pImg, 'playerImageModel' => $playerImageModel, 'updateErrorMessage' => $updateErrorMessage));
			 }
			 else {
				 $this->render('editProfile', array('userModel' => $userModel, 'emailModels' => $emailModels, 'addressModels' => $addressModels,
				 'mainPropertiesModels' => $mainPropertiesModels, 'ttPropertiesModels' => $ttPropertiesModels, 'phoneModels' => $phoneModels, 'pImg' => $pImg, 'playerImageModel' => $playerImageModel));
			 }
		 }
		 else {
		 	$this->redirect(Yii::app()->homeUrl);
		 }
	 }
	 
	 public function connectToFacebook(){
	 
	 	if(!Yii::app()->user->getIsGuest()) {
	 	
	 		$u_id = Yii::app()->user->id;
	 		$user = User::model()->findByPk($u_id);
	 	
	 		if (Yii::app()->request->isAjaxRequest) {
	 			
	 			
// 	 			echo CJSON::encode(array('valid' => false, 'error' => $err ));
	 			echo CJSON::encode(array('valid' => true));
	 			return;
	 		}
	 		
	 		$this->redirect($this->createUrl('news/newsFeed'));
	 		return;
	 	}
	 	
	 	$this->redirect($this->createUrl('news/newsFeed'));
	 	return;
	 }
	 
	 /**
	  * 
	  * @throws CException
	  */
	 public function actionChangePw() {
	 	
	 	if(!Yii::app()->user->getIsGuest()) {
	 		
	 		$u_id = Yii::app()->user->id;
	 		$user = User::model()->findByPk($u_id);
	 		
	 		if (Yii::app()->request->isAjaxRequest) {
	 			
	 			$this->layout=false;
	 			header('Content-type: application/json');
	 			
	 			$postData = file_get_contents('php://input');
	 			$post = CJSON::decode($postData, true);
	 			
	 			if(isset($post['old_password']) && isset($post['new_password_1']) && isset($post['new_password_2'])) {
	 				$err = '';
	 				$transaction = Yii::app()->db->beginTransaction();
	 				try
	 				{
		 				/*
		 				 * check old pw		 				 
		 				 */
	 					if($user->password !== crypt($post['old_password'], $user->password))
	 					{
	 						$err = 'Das alte Passwort ist falsch.';
	 						throw new CException($err);
	 					}
		 				
		 				/*
		 				 * pw_1 > 8
		 				*/
		 				if(strlen($post['new_password_1']) < 8) {
		 					$err = 'Passwort muss mindestens 8 Zeichen lang sein.';
		 					throw new CException($err);
		 				}
	 					
	 					
		 				/*
		 				 * pw_1 == pw_2
		 				*/	 				
	 					if($post['new_password_1'] !== $post['new_password_2']) {
	 						$err = 'Passwörter stimmen nicht überein.';
	 						throw new CException($err);
	 					}
	 					
	 					
	 					/*
	 					 * crypt and assign new pw
	 					 */
	 					$salt = User_Identity::blowfishSalt();
	 					$user->password = crypt($post['new_password_1'], $salt);
	 					
	 					/*
	 					 * validate and save new pw
	 					 */
	 					if($user->validate(array('password'))) {
	 						$updated = $user->update(array('password'));
	 						if($updated) {
	 							$transaction->commit();
	 						}
	 						else {
	 							$err = 'Update error';
	 							throw new CException($err);
	 						}
	 					}
	 					else {
	 						$err = 'validation error';
	 						throw new CException($err);
	 					}
	 				}
	 				catch(Exception $e)
	 				{
	 					$transaction->rollback();
	 					$err = '';
	 					echo CJSON::encode(array('valid' => false, 'error' => $err ));
	 					return;
	 				}
	 				
	 				echo CJSON::encode(array('valid' => true));
	 				return; 				
	 			}
	 			
	 			
	 			echo CJSON::encode(array('valid' => false));
	 			return;
	 		}
	 	}
	 	
	 	
	 	$this->redirect($this->createUrl('news/newsFeed'));
		return;
	 }
	 
	 
	 /**
	  * displays a overview page with all players that belong to the 
	  * user's current club (he has logged in for).
	  * 
	  * The user needs at least 'club_manager' rights.
	  */
	 public function actionEditProfileOverview() {
	 	
	 	$access = Yii::app()->user->checkAccess('club_manager');
	 	if(!Yii::app()->user->getIsGuest() && $access) {
	 		
	 		$clubId = Yii::app()->user->getState('club_id');
	 		$clubPlayers = HasClubs::model()->findAllByAttributes(array('club_id' => $clubId, 'activated' => 'true'));
	 		
	 		$players = array();
	 		foreach ($clubPlayers as $clubPlayer) {
	 			$player = User::model()->findByPk($clubPlayer->u_id);
	 			if($player) {
	 				$player->password = Null;
	 				$players[] = $player;
	 			}
	 		}
	 			
	 		$this->render('editProfileOverview', array('players' => $players));
	 		return;
	 	}
	 	
	 	$this->redirect(Yii::app()->homeUrl);
	 	return;
	 }
	 
	 
	 
	 /**
	  * deletes an user's profile image. 
	  * The corresponding ImageModel and the image onto the file system
	  * will be deleted. UserMainProperties model will get an Null entry.
	  * 
	  * If some of the actions could not be performed, a db rollback is
	  * performed to guarantee data consistancy. 
	  */
	 public function actionDeleteProfileImage() {
	 	
	 	if(!Yii::app()->user->getIsGuest()) {
	 		// TODO: assert(isset(Yii::app()->user->id));
	 		
	 		$u_id = Yii::app()->user->id;
	 		$user = User::model()->findByPk($u_id);
	 		$transaction = Yii::app()->db->beginTransaction();
	 		try
	 		{
		 		if(isset($user)) {
		 			$mainPropertiesModels =  UserMainProperties::model()->findByPk($u_id);
		 			if(isset($mainPropertiesModels)) {
		 				if(isset($mainPropertiesModels->img_id)) {	 		
		 					
	 						$imgId = $mainPropertiesModels->img_id;
	 						$mainPropertiesModels->img_id = Null;
	 						if($mainPropertiesModels->validate(array('img_id'))) {
	 							$updated = $mainPropertiesModels->update(array('img_id'));
	 							if($updated) {
	 								$imgModel = ImageModel::model()->findByPk($imgId);
	 								if(isset($imgModel)) {
	 									$fileName = $imgModel->file_name;
	 									$deleted = $imgModel->delete();
	 									if($deleted) {
	 										if(isset($fileName)) {
	 											if(file_exists($fileName)) {
	 												unlink($fileName);	 												
	 											}
	 										}
	 										
	 										$transaction->commit();
	 									}
	 									else {
	 										throw new CDbException('can not delete ImageModel with img_id: '.$imgId);
	 									}
	 								} 
	 								else {
	 									throw new CDbException('ImageModel for img_id: '.$imgId. ' not found');
	 								}
	 							}
	 							else {
	 								throw new CDbException('could not update the UserMainProperties');
	 							}
	 						}
	 						else {
	 							throw new CDbException('could not validate the UserMainProperties');
	 						}	
		 				}
		 				else {
		 					throw new CDbException('UserMainProperties has no image id');
		 				}
		 			}
		 			else {
		 				throw new CDbException('UserMainProperties not found');
		 			}
		 		}
		 		else {
		 			throw new CDbException('User not found');
		 		}	
	 		}
	 		catch(Exception $e) {
	 			
	 			$transaction->rollback();
	 		}	 		
	 	}
	 	
	 	$this->forward('user/editProfile', true);	 	
	 	return;
	 }	
	 
	 
	
}
?>