<?php

/**
 * LoginForm class.
 * LoginForm is the data structure for keeping
 * user login form data. It is used by the 'login' action of 'SiteController'.
 */
class LoginForm extends CFormModel
{
	public $email;
	public $password;
	public $clubId;
	public $rememberMe;
	private $_identity;
        // private $authenticated = false;

	/**
	 * Declares the validation rules.
	 * The rules state that email and password are required,
	 * and password needs to be authenticated.
	 */
	public function rules()
	{
		return array(
                    // valid email address
                    // array('email', 'email'),
                    // email and password are required
                    array('email, password', 'required'),
                    // rememberMe needs to be a boolean
                    array('rememberMe', 'boolean'),
                    // password needs to be authenticated
                    array('password', 'authenticate'),
		);
	}

	/**
	 * Declares attribute labels.
	 */
	public function attributeLabels()
	{
		return array(
			'rememberMe'=>'eingeloggt bleiben',
		);
	}

	/**
	 * Authenticates the password.
	 * This is the 'authenticate' validator as declared in rules().
	 */
	public function authenticate($attribute,$params)
	{
		if(!$this->hasErrors())
		{
                    $this->_identity=new User_Identity(Null,$this->password);
                    $this->_identity->useEmail($this->email);
                    $this->_identity->useClub($this->clubId);
                    if($this->_identity->authenticate() != CUserIdentity::ERROR_NONE)
                    {
                        $this->addError('password','Incorrect email or password.');
                    }
		}
	}

	/**
	 * Logs in the user using the given email and password in the model.
	 * @return boolean whether login is successful
	 */
	public function login()
	{
		if($this->_identity===null)
		{
                    $this->_identity=new User_Identity(Null,$this->password);
                    $this->_identity->useEmail($this->email);
                    $this->_identity->useClub($this->clubId);
                    $this->_identity->authenticate();
		}
		if($this->_identity->errorCode == CUserIdentity::ERROR_NONE)
		{
                    /*
                     * store login date within DB
                     */
                    $connection=Yii::app()->db;  
                    $sql =  "UPDATE tbl_user SET ".
                            "last_login = '". "now()" ."' ".
                            "WHERE u_id = '".$this->_identity->username."';";                  
                    $connection->createCommand($sql)->execute();
                    
                    
                    $duration=$this->rememberMe ? 3600*24*30 : 0; // 30 days
                    Yii::app()->user->login($this->_identity,$duration);
                    
                    return CUserIdentity::ERROR_NONE;
		}
                
                return $this->_identity->errorCode;                
	}
}
